HarpConnection

Struct HarpConnection 

pub struct HarpConnection { /* private fields */ }

Implementations

Source

impl HarpConnection

pub fn build() -> Result<Self>

Create the harp data directory and data file, read it and deserialize it into the model.

pub fn save(self) -> Result<()>

Remember to call this at the end of your mutating harp operations. If you only ever just look at the data rather than modify it, no need to call this.

pub fn entry_ref(&self, section: &str, register: &str) -> Option<&Vec<String>>

Get a reference to the Vec of your desired register, but only if both the section and the register already exist.

pub fn entry_mut( &mut self, section: String, register: String, ) -> &mut Vec<String>

Get a mutable reference to the Vec of your desired register, creating the section and the register in the process, if necessary.

pub fn section_ref( &self, section: &str, ) -> Option<&HashMap<String, Vec<String>>>

Get a reference to the HashMap of all the registers in this section, if it even exists. If the section doesn’t exist, it is not created, unlike with section_mut().

pub fn section_mut( &mut self, section: String, ) -> &mut HashMap<String, Vec<String>>

Get a mutable reference to the HashMap of all the registers in this section, creating the section if necessary.