Create a HarpConnection using HarpConnection::build — this ensures the data file is created, and is valid json that you can modify.
Then, use HarpConnection::entry_mut to get a mutable reference to the vector of the register that you want to interact with.
Do all the changes you want to do, and call HarpConnection::save. This will write the model back into the json data file.
If you don’t intend to modify the data, you can instead use HarpConnection::entry_ref.
entry_ methods are for looking into some specific register; but if you want to mutate / view all the registers in a section, use HarpConnection::section_mut / HarpConnection::section_ref