pub struct HarpConnection { /* private fields */ }Implementations
Sourceimpl HarpConnection
impl HarpConnection
Sourcepub fn build() -> Result<Self>
pub fn build() -> Result<Self>
Create the harp data directory and data file, read it and deserialize it into the model.
Sourcepub fn save(self) -> Result<()>
pub fn save(self) -> Result<()>
Remember to call this at the end of your mutating harp operations. If you only ever just look at the data rather than modify it, no need to call this.
Sourcepub fn entry_ref(&self, section: &str, register: &str) -> Option<&Vec<String>>
pub fn entry_ref(&self, section: &str, register: &str) -> Option<&Vec<String>>
Get a reference to the Vec of your desired register, but only if both the section and the register already exist.
Sourcepub fn entry_mut(
&mut self,
section: String,
register: String,
) -> &mut Vec<String>
pub fn entry_mut( &mut self, section: String, register: String, ) -> &mut Vec<String>
Get a mutable reference to the Vec of your desired register, creating the section and the register in the process, if necessary.